@@ -1,12 +1,12 @@
+use async_net::Ipv4Addr;
 use bevy::app::ScheduleRunnerSettings;
 use bevy::prelude::*;
-use bevy_eventwork::{ConnectionId, NetworkData, NetworkServer, ServerNetworkEvent};
+use bevy_eventwork::{ConnectionId, NetworkData, Network, NetworkEvent};
 use std::net::{IpAddr, SocketAddr};
 use std::ops::Deref;
-use std::str::FromStr;
 use std::time::Duration;
 
-use bevy_eventwork::tcp::{NetworkSettings, TcpServerProvider};
+use bevy_eventwork::tcp::{NetworkSettings, TcpProvider};
 
 mod shared;
 
@@ -21,8 +21,8 @@ fn main() {
 
     // Before we can register the potential message types, we
     // need to add the plugin
-    app.add_plugin(bevy_eventwork::ServerPlugin::<
-        TcpServerProvider,
+    app.add_plugin(bevy_eventwork::EventworkPlugin::<
+        TcpProvider,
         bevy::tasks::TaskPool,
     >::default());
 
@@ -33,10 +33,7 @@ fn main() {
     app.add_startup_system(setup_networking);
     app.add_system(handle_connection_events);
     app.add_system(handle_messages);
-    app.insert_resource(NetworkSettings::new((
-        IpAddr::from_str("127.0.0.1").unwrap(),
-        8080,
-    )));
+    app.insert_resource(NetworkSettings::default());
 
     app.run();
 }
@@ -44,7 +41,7 @@ fn main() {
 // On the server side, you need to setup networking. You do not need to do so at startup, and can start listening
 // at any time.
 fn setup_networking(
-    mut net: ResMut<NetworkServer<TcpServerProvider>>,
+    mut net: ResMut<Network<TcpProvider>>,
     settings: Res<NetworkSettings>,
     runtime: Res<bevy::tasks::TaskPool>,
 ) {
@@ -54,7 +51,7 @@ fn setup_networking(
 
     let _socket_address = SocketAddr::new(ip_address, 9999);
 
-    match net.listen(runtime.deref(), &settings) {
+    match net.listen(SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8080),runtime.deref(), &settings) {
         Ok(_) => (),
         Err(err) => {
             error!("Could not start listening: {}", err);
@@ -70,11 +67,11 @@ struct Player(ConnectionId);
 
 fn handle_connection_events(
     mut commands: Commands,
-    net: Res<NetworkServer<TcpServerProvider>>,
-    mut network_events: EventReader<ServerNetworkEvent>,
+    net: Res<Network<TcpProvider>>,
+    mut network_events: EventReader<NetworkEvent>,
 ) {
     for event in network_events.iter() {
-        if let ServerNetworkEvent::Connected(conn_id) = event {
+        if let NetworkEvent::Connected(conn_id) = event {
             commands.spawn_bundle((Player(*conn_id),));
 
             // Broadcasting sends the message to all connected players! (Including the just connected one in this case)
@@ -90,7 +87,7 @@ fn handle_connection_events(
 // Receiving a new message is as simple as listening for events of `NetworkData<T>`
 fn handle_messages(
     mut new_messages: EventReader<NetworkData<shared::UserChatMessage>>,
-    net: Res<NetworkServer<TcpServerProvider>>,
+    net: Res<Network<TcpProvider>>,
 ) {
     for message in new_messages.iter() {
         let user = message.source();
